@@ -1,5 +1,5 @@
 package POEx::ZMQ;
-$POEx::ZMQ::VERSION = '0.005004';
+$POEx::ZMQ::VERSION = '0.005005';
 use strictures 1;
 
 use Scalar::Util 'blessed';
@@ -85,11 +85,12 @@ POEx::ZMQ - Asynchronous ZeroMQ sockets for POE
         # Handle the usual ZeroMQ message framing scheme by capturing
         # prefixed identities including empty message delimiter, followed
         # by our message body:
-        my ($envelope, $body) = $parts->tail;
+        my $envelope = $parts->items_before(sub { $_ eq '' });
+        my $content  = $parts->items_after(sub { $_ eq '' });
 
         # $_[SENDER] was the ROUTER socket, send a response back to origin:
         $_[KERNEL]->post( $_[SENDER], send_multipart =>
-          [ $envelope, 'foo' ]
+          [ $envelope, '', 'foo' ]
         );
       },
     },
